nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

CpuCtrl

Struct CpuCtrl 

#[repr(transparent)]
pub struct CpuCtrl(pub u32);
PGC CPU Control Register

Tuple Fields

0: u32

Implementations

Source

impl CpuCtrl

pub const fn pcr(&self) -> CpuCtrlPcr

Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up

pub const fn set_pcr(&mut self, val: CpuCtrlPcr)

Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up