nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

MegaCtrl

Struct MegaCtrl 

#[repr(transparent)]
pub struct MegaCtrl(pub u32);
PGC Mega Control Register

Tuple Fields

0: u32

Implementations

Source

impl MegaCtrl

pub const fn pcr(&self) -> MegaCtrlPcr

Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up

pub const fn set_pcr(&mut self, val: MegaCtrlPcr)

Power Control PCR must not change from power-down request (pdn_req) assertion until the target subsystem is completely powered up